%name:      add_dimension_to_coeff.m
%objective: add dimension to the matrices and vectors obtained from the
%output file from WADAM and generate the total mass, stiffness, damping,
%motion and excitation matrices.
%% 

function [M_total, C_total, Fexc_dim, X_dim,K_total]= add_dimension_to_coeff(Added_mass, Damping, Fexc, Motion ,Mass_inertia,Restoring,Viscous_damping,Freq_ind_added_mass)
global RO G L VOL WA 
k=[1:6:300]; %to allocate start positions of each added mass and damping matrices

%Allocate output matrices
%Frequency dependent
[n m]=size(Added_mass);
[o p]=size(Fexc);
M_total=zeros(n,m-1); % n x 6 matrix
C_total=zeros(n,m-1);
Fexc_dim=zeros(o,p); 
X_dim=zeros(o,p);
K_total=zeros(6,6);

%% Frequency dependent results : 
for i = 1:length(k)
    n=k(i);
    %Added mass matrix
    M_total(n:(n+2),1:3)=Added_mass(n:(n+2),2:4)*RO*VOL + Mass_inertia(1:3,2:4)*RO*VOL;             % i = 1:3, j=1:3 
    M_total(n:(n+2),4:6)=Added_mass(n:(n+2),5:7)*RO*VOL*L + Mass_inertia(1:3,5:7)*RO*VOL*L;         % i = 1:3, j=4:6
    M_total(n+3:(n+5),1:3)=Added_mass(n+3:(n+5),2:4)*RO*VOL*L + Mass_inertia(4:6,2:4)*RO*VOL*L;     % i = 4:6, j=1:3
    M_total(n+3:(n+5),4:6)=Added_mass(n+3:(n+5),5:7)*RO*VOL*L*L + Mass_inertia(4:6,5:7)*RO*VOL*L*L; % i = 4:6, j=4:6
    %Damping matrix includes viscous damping from morrison, Total damping from WADAM1.LIS 
    C_total(n:(n+2),1:3)=Damping(n:(n+2),2:4)*RO*VOL*sqrt(G/L);% + Viscous_damping(1:3,2:4)*RO*VOL*sqrt(G/L);       % i = 1:3, j=1:3 
    C_total(n:(n+2),4:6)=Damping(n:(n+2),5:7)*RO*VOL*sqrt(G*L);% + Viscous_damping(1:3,5:7)*RO*VOL*sqrt(G*L);       % i = 1:3, j=4:6
    C_total(n+3:(n+5),1:3)=Damping(n+3:(n+5),2:4)*RO*VOL*sqrt(G*L);% + Viscous_damping(4:6,2:4)*RO*VOL*sqrt(G*L);   % i = 4:6, j=1:3
    C_total(n+3:(n+5),4:6)=Damping(n+3:(n+5),5:7)*RO*VOL*L*sqrt(G*L);% + Viscous_damping(4:6,5:7)*RO*VOL*L*sqrt(G*L); % i = 4:6, j=4:6
end

%% Static results

%Hydrostatic restoring coefficient matrix 
K_total(1:3,1:3) = Restoring(1:3,2:4)*RO*VOL*(G/L);  
K_total(1:3,4:6)= Restoring(1:3,5:7)*RO*VOL*G;
K_total(4:6,1:3)= Restoring(4:6,2:4)*RO*VOL*G;
K_total(4:6,4:6)= Restoring(4:6,5:7)*RO*VOL*G*L;

%viscous damping and frequency independent added mass included in Added
%Mass and Damping by default


%% MOTIONS and excitation forces
for i =1:6:length(Motion)
    Fexc_dim(i:i+2,2:end-1)=Fexc(i:i+2,2:end-1)*RO*VOL*G*(WA/L);
    Fexc_dim(i+3:i+5,2:end-1)=Fexc(i+3:i+5,2:end-1)*RO*VOL*G*WA;    
    X_dim(i:i+2,2:end-1)=Motion(i:i+2,2:end-1)*WA;
    X_dim(i+3:i+5,2:end-1)=Motion(i+3:i+5,2:end-1)*(WA/L);    
    
end

Fexc_dim(:,1)=Fexc(:,1);
Fexc_dim(:,end)=Fexc(:,end);
X_dim(:,1)=Motion(:,1);
X_dim(:,end)=Motion(:,end);

end

%% EXTRA DESCRIPTION : 
%added mass 1st quadrant : multiply by Ro*vol
%%added mass diagonal quadrants : multiply by Ro*vol*L
%added mass last quadrant : multiply by Ro*vol*L*L

%MASS INERTIA MATRIX NON-DIMENSIONALIZED BY:    RO*VOL,            RO*VOL*L           RO*VOL*L*L 
%ADDED MASS MATRIX   NON-DIMENSIONALIZED BY:    RO*VOL,            RO*VOL*L           RO*VOL*L*L 
%DAMPING MATRIX      NON-DIMENSIONALIZED BY:    RO*VOL*SQRT(G/L)   RO*VOL*SQRT(G*L)   RO*VOL*L*SQRT(G*L)
%RESTORING MATRICES  NON-DIMENSIONALIZED BY:    RO*VOL*G/L,        RO*VOL*G           RO*VOL*G*L 
%                                               i=1:3              j=4:6
%EXCITING FORCES     NON-DIMENSIONALIZED BY:    RO*VOL*G*WA/L      RO*VOL*G*WA 
%MOTIONS             NON-DIMENSIONALIZED BY:    WA                 WA/L               (4-6 IN RADIANS)
