% name : plot_2nd_order_forces
% objective : to calculate the absolute value of the complex QTF, plot
% surface of QTF for surge heave and pitch.
% call : sort_to_get_surface_plotQTF.m
%%
function [Omega_diff_all, Force_diff_all] = plot_2nd_order_forces(Surge,Heave,Pitch)
%Difference frequency forces
%Freq 1   Freq 2  Sum/Diff  RealVal    ImagVal   Amplitude   Phase


Abs_F1=Surge(:,6);
Abs_F3=Heave(:,6);
Abs_F5=Pitch(:,6);
Phase_F1=Surge(:,7);
Phase_F3=Heave(:,7);
Phase_F5=Pitch(:,7);

F1_diff=zeros(length(Abs_F1),1);
F3_diff=zeros(length(Abs_F3),1);
F5_diff=zeros(length(Abs_F5),1);

n=length(Abs_F1);
for i =1:n
   F1_diff(i)= Abs_F1(i)*exp(1i*Phase_F1(i));
   F3_diff(i)= Abs_F3(i)*exp(1i*Phase_F3(i));
   F5_diff(i)= Abs_F5(i)*exp(1i*Phase_F5(i));
end

%surge_surface plot
[freq2, freq1, surface] = sort_to_get_surface_plotQTF(abs(F1_diff), Surge(:,1:2));

figure(55)
surf(freq2,freq1,surface)
title('Surge QTF')

%heave surface plot
[freq2, freq1, surface] = sort_to_get_surface_plotQTF(abs(F3_diff), Heave(:,1:2));

figure(56)
surf(freq2,freq1,surface)
title('heave QTF')

%Pitch surface plot
[freq2, freq1, surface] = sort_to_get_surface_plotQTF(abs(F5_diff), Pitch(:,1:2));

figure(57)
surf(freq2,freq1,surface)
title('Pitch QTF')
%

omega_F1=Surge(:,3); %representing the omega_i - omega_j
omega_F3=Heave(:,3);
omega_F5=Pitch(:,3);

Omega_diff_all=[omega_F1 omega_F3 omega_F5];
Force_diff_all=[abs(F1_diff) abs(F3_diff) abs(F5_diff)];

figure(50)
plot(omega_F1,abs(F1_diff),'*',omega_F3,abs(F3_diff),'*')
legend('F1_diff','F3_diff')
title('Forces versus difference frequency')
xlabel('omega_j-omega_i [rad/s]')
ylabel('[N]') % ? 

figure(51)
plot(omega_F5,abs(F5_diff),'*')
legend('F5_diff')
title('Pitching moment versus difference frequency')
xlabel('omega_j - omega_i [rad/s]')
ylabel('[Nm]') % ? 

end


