%-----------Kristine Byum Riste 2016-------------------------------------%
%Objective: Calculate hydrodynamic results for dynamic equation of motion
%           by use of results from simulations in HydroD
%-------------------------------------------------------------------------%
%% 
clc
clear
close all

%Declare global variables as given in WADAM output
global RO G L VOL WA 

RO   =  0.1025E+04; %kg/m^3
G    =  0.9810E+01; %m/s^2
VOL  =  0.4499E+04; %m^3
L    =  0.1000E+03; %m
WA   =  1.0 ;       %m (IF NOT GIVEN AS INPUT)

%declare parameter
%%
% Condition 1:3
% condition 1 :ws= 8 m/s condition 2 :ws= 18 m/s condition 3 :ws= 42 m/s
ws=[8 18 42]; %windspeed
condition=3; %Select condition
filepath =sprintf('%s%d%s','C:\Users\Kristine\Dropbox\MATLAB\Master Thesis\cleanup of code  2\environmental statistics\jonswap_spectral_parameters_ws',ws(condition),'.dat');
FileIDJonswap=fopen(filepath,'r');
%Read data for JONSWAP spectra generated by WAFO
data_wave_spectrum = textscan(FileIDJonswap,'%f %f\n');
data_wave_spectrum = cell2mat(data_wave_spectrum);
fclose(FileIDJonswap);

%%
%Reads non-dimensional results from WADAM output file
[Added_mass, Wave_description, Damping, Fexc, Motion,Mass_inertia,Restoring,Viscous_damping,Freq_ind_added_mass] = read_WADAM_output();
%%
%Read 2nd-order results from WADAM output file
[Surge_2nd,Heave_2nd,Pitch_2nd,Drift_mean] = read_WADAM_2nd_order_output();
%% sort the results for mean drift into 6 dof, and plot them, comparison
%between pressure integration(6 dof) and far field integration(horizontal F1 F2 and F6)
[Drift_sorted] = plot_drift_forces(Drift_mean); 
%% Plot the 2nd order forces, QTF for surge heave pitch. surface plot wj wi
[Omega_diff_all, Force_diff_all]= plot_2nd_order_forces(Surge_2nd,Heave_2nd,Pitch_2nd);
%% 
%Add dimensions to the coefficient matrices extracted from the WADAM.lis
%file
%output, generate the total matrices
[M_tot, C_tot, Fexc_tot, X_tot,K_tot] = add_dimension_to_coeff(Added_mass, Damping, Fexc, Motion,Mass_inertia,Restoring,Viscous_damping,Freq_ind_added_mass);
% TEST WITH PHASE IN RADIANS
Fexc_tot(:,5)=Fexc_tot(:,5)*(pi/180);
X_tot(:,5)=X_tot(:,5)*(pi/180);
%% Add restoring from Mooring Lines
% 
omega_Mooring = [0.0587 0.0503 0.0917]; %natural periods in surge sway and yaw
for i = 1:length(omega_Mooring)
    [M_w, C_w, Fexc_w,X_w]=local_coeff_matrix(omega_Mooring(i),M_tot,C_tot,Fexc_tot,X_tot,Wave_description);
    [K_tot] = add_mooring_restoring(M_w, K_tot,i,omega_Mooring(i));
end
% 
% Perform eigenvalue analysis in order to obtain the terms due to damping

%% ===========Complex transfer function :================================== 
% H_zeta_F = complex transfer function: F_waves(w) = H_zeta_F*exp(i*w*t)
% H_zeta_X = complex platform motions i = 1:6 dof, for waves propagating in x-direction
% H_F_X = complex force-motion transfer function [6x6], one row [1x6] for each dof

[H_zeta_X, H_zeta_F, X_comp, H_F_X1, H_F_X3, H_F_X5]=transfer_motions(M_tot,C_tot,K_tot,Wave_description,X_tot,Fexc_tot,Drift_sorted);
%% Establish displacements, velocities and accelerations for 6 DOF
%NB for t = 0, hence exp(i*omega*t) =1; 
%Ps. cheat on H_zeta_X(:,5) = X_comp(:,5);
%Output is abs(X_w) etc.
[X_w, dX_w, ddX_w, w] = motions(H_zeta_X,Wave_description);

%compare the results from HydroD and other transferfunction 
[error]=comparison(X_w,X_comp,w);

%% 4 =include mean drift forces, 3 = only difference-frequency

% Calculate the force spectrum for 2nd order loads based on QTF
[S11_2nd, OMEGA] = second_order_wave_spectra_disctretization_4(Surge_2nd,data_wave_spectrum); %compute power spectra surge
[S33_2nd, OMEGA] = second_order_wave_spectra_disctretization_4(Heave_2nd,data_wave_spectrum); %compute power spectra heave
[S55_2nd, OMEGA] = second_order_wave_spectra_disctretization_4(Pitch_2nd,data_wave_spectrum); %compute power spectra pitch
S11_2nd = S11_2nd;%*10^-6;%[kN^2 m^2 rad/s]
S33_2nd = S33_2nd;%*10^-6; %[kN^2 m^2 rad/s]
S55_2nd = S55_2nd;%*10^-6; %[kNm^2 m^2 rad/s]
%% 2nd order motion spectrum
% Compute the second order motion spectrum based on the 2nd order force
% spectrum and the transferfunction between force and motion from dynamic
% equation of motion
[S11_2nd_motion] = motion_spectra_2nd(H_F_X1,S11_2nd, OMEGA,w,1); %compute power spectra surge
[S33_2nd_motion] = motion_spectra_2nd(H_F_X3,S33_2nd, OMEGA,w,3);  %compute power spectra heave
[S55_2nd_motion] = motion_spectra_2nd(H_F_X5,S55_2nd, OMEGA,w,5);  %compute power spectra pitch
%% Compare thrust force spectrum 
fid1=fopen('Wind_force_spectrum_ws8.dat','r');
data8 = textscan(fid1,'%f %f\n');
data8 = cell2mat(data8);
fclose(fid1);

hubheight=90;%m
%Motions spectrum wind induced motions for surge and heave ws 8 m/s
S11_wind8=data8(:,2)*9/(2*pi); %Originally in [Hz^-1] for 1 blade 
S55_wind8=(data8(:,2)*hubheight^2)*9/(2*pi);
OMEGA_wind8=data8(:,1);

fid2=fopen('Wind_force_spectrum_ws18.dat','r');
data18 = textscan(fid2,'%f %f\n');
data18 = cell2mat(data18);
fclose(fid2);

%Motions spectrum wind induced motions for surge and heave ws 18 m/s
S11_wind18=data18(:,2)*9/(2*pi);
S55_wind18=(data18(:,2)*hubheight^2)*9/(2*pi);
OMEGA_wind18=data18(:,1);

%% Open files for comparison with thrust force spectrum 
%Calculate area and peak frequencies.
fid=fopen('TD_thrust_force_spectrum_with_pitch_ws8_test.dat','r');
data8_TD_pitch = textscan(fid,'%f %f\n');
data8_TD_pitch = cell2mat(data8_TD_pitch);
fclose(fid);
Area_TD(1)=trapz(data8_TD_pitch(:,1),data8_TD_pitch(:,2));
row=find(data8_TD_pitch(:,2)==max(data8_TD_pitch(:,2)));
peak_TD(1)=data8_TD_pitch(row);


fid=fopen('TD_thrust_force_spectrum_with_pitch_ws18_test.dat','r');
data18_TD_pitch = textscan(fid,'%f %f\n');
data18_TD_pitch = cell2mat(data18_TD_pitch);
fclose(fid);
Area_TD(2)=trapz(data18_TD_pitch(:,1),data18_TD_pitch(:,2));
row=find(data18_TD_pitch(:,2)==max(data18_TD_pitch(:,2)));
peak_TD(2)=data18_TD_pitch(row);

fid=fopen('TD_thrust_force_spectrum_with_surge_ws8_test.dat','r')
data8_TD_surge = textscan(fid,'%f %f\n');
data8_TD_surge = cell2mat(data8_TD_surge);
fclose(fid);
Area_TD(3)=trapz(data8_TD_surge(:,1),data8_TD_surge(:,2));
row=find(data8_TD_surge(:,2)==max(data8_TD_surge(:,2)));
peak_TD(3)=data8_TD_surge(row);

fid=fopen('TD_thrust_force_spectrum_with_surge_ws18_test.dat','r')
data18_TD_surge = textscan(fid,'%f %f\n');
data18_TD_surge = cell2mat(data18_TD_surge);
fclose(fid);
Area_TD(4)=trapz(data18_TD_surge(:,1),data18_TD_surge(:,2));
row=find(data18_TD_surge(:,2)==max(data18_TD_surge(:,2)));
peak_TD(4)=data18_TD_surge(row);

%% Calculate motion spectrum for wind induced motions based on thrust force in global coordingates 
[S11_Motion_wind8] = motion_spectra_2nd(H_F_X1,S11_wind8, OMEGA_wind8,w,1); %compute power spectra surge
[S11_Motion_wind18] = motion_spectra_2nd(H_F_X1,S11_wind18, OMEGA_wind18,w,1); %compute power spectra surge
%peak frequencies 
row=find(S11_Motion_wind8==max(S11_Motion_wind8));
peak_FD(1)=OMEGA_wind8(row);
row=find(S11_Motion_wind18==max(S11_Motion_wind18));
peak_FD(2)=OMEGA_wind18(row);

[S55_Motion_wind8] = motion_spectra_2nd(H_F_X5,S55_wind8, OMEGA_wind8,w,5); %compute power spectra pitch
[S55_Motion_wind18] = motion_spectra_2nd(H_F_X5,S55_wind18, OMEGA_wind18,w,5); %compute power spectra pitch
row=find(S55_Motion_wind8==max(S55_Motion_wind8));
%peak frequencies 
peak_FD(3)=OMEGA_wind8(row);
row=find(S55_Motion_wind18==max(S55_Motion_wind18));
peak_FD(4)=OMEGA_wind18(row);
%Area from FD-method
Area_FD(1)=trapz(OMEGA_wind8,S11_Motion_wind8);
Area_FD(2)=trapz(OMEGA_wind8,S55_Motion_wind8);
Area_FD(3)=trapz(OMEGA_wind18,S11_Motion_wind18);
Area_FD(4)=trapz(OMEGA_wind18,S55_Motion_wind18);

%% Try to interpolate H_zeta_X
S11_2nd_motion_new=interp1(OMEGA,S11_2nd_motion,data_wave_spectrum(:,1),'linear','extrap');
S33_2nd_motion_new=interp1(OMEGA,S33_2nd_motion,data_wave_spectrum(:,1),'linear','extrap');
S55_2nd_motion_new=interp1(OMEGA,S55_2nd_motion,data_wave_spectrum(:,1),'linear','extrap');

%% plot comparison
w_interp=data_wave_spectrum(:,1);
figure(1000)
subplot(1,3,1)
plot(w_interp,S11_2nd_motion_new,'+-',OMEGA,S11_2nd_motion,'*')

subplot(1,3,2)
plot(w_interp,S33_2nd_motion_new,'+-',OMEGA,S33_2nd_motion,'*')

subplot(1,3,3)
plot(w_interp,S55_2nd_motion_new,'+-',OMEGA,S55_2nd_motion,'*')


%% Spectral analysis
%Interpolate wave spectrum data to represent Wave_description from WADAM
S_w=interp1(data_wave_spectrum(:,1),data_wave_spectrum(:,2),w);

%Establish force spectrum
S_F=force_spectrum(S_w,H_zeta_F,w);
S_F=S_F*10^-6; % [kN^2 m^2 s/rad] / [kNm^2 m^2 s/rad]

%Establish motion spectrum
S_X=force_spectrum(S_w,H_zeta_X,w); %[m^2 s/rad]  / [rad^2 s/rad]

%% Try to interpolate H_zeta_X
H_zeta_X_abs=abs(H_zeta_X);
H_zeta_X_abs=interp1(w,H_zeta_X_abs,data_wave_spectrum(:,1),'linear','extrap');
S_X=force_spectrum(data_wave_spectrum(:,2),H_zeta_X_abs,data_wave_spectrum(:,1));

%% PLOT Linear MOTION spectrum for Surge, Heave, Pitch
w_interp=data_wave_spectrum(:,1);
figure(103)
%subplot(2,3,1)
plot(w_interp,S_X(:,1));
legend('S_X surge');
ylabel('m^2 s/rad')
xlabel('Wave frequency [rad/s]')
figure(104)
%subplot(2,3,3)
plot(w_interp,S_X(:,3));
legend('S_X heave');
ylabel('m^2 s/rad')
xlabel('Wave frequency [rad/s]')

figure(105)
%subplot(2,3,5)
plot(w_interp,S_X(:,5));
legend('S_X pitch');
ylabel('rad^2 s/rad')
xlabel('Wave frequency [rad/s]')
%% COMPARISON WITH SRA 
freq_linear=w_interp;
freq_2nd=OMEGA;
[std_comparisonWF, omega_peak_comparisonWF, std_comparisonLF ,omega_peak_comparisonLF] = comparison_with_SRA2(S_X,S11_2nd_motion,S33_2nd_motion,S55_2nd_motion,freq_linear,freq_2nd,condition);
show=[std_comparisonWF(:,1);std_comparisonWF(:,2);omega_peak_comparisonWF(:,1);omega_peak_comparisonWF(:,2);std_comparisonLF(:,1);std_comparisonLF(:,2);omega_peak_comparisonLF(:,1);omega_peak_comparisonLF(:,2)];
%% PLOT Linear + 2nd order MOTION spectrum for Surge, Heave, Pitch
figure(110)
%subplot(2,3,1)
h=plot(w_interp,S_X(:,1),OMEGA,S11_2nd_motion);
set(h(1),'LineStyle','-','color',[0.0 0.2 0.6]);
set(h(2),'LineStyle','--','color',[0.0 0.2 0.0]);
legend('S_X surge', 'S_X 2nd');
ylabel('m^2 s/rad')
xlabel('Wave frequency [rad/s]')
xlim([0 1.5])
ylim([0 45])

figure(111)
%subplot(2,3,3)
h=plot(w_interp,S_X(:,3),OMEGA,S33_2nd_motion);
set(h(1),'LineStyle','-','color',[0.0 0.2 0.6]);
set(h(2),'LineStyle','--','color',[0.0 0.2 0.0]);
legend('S_X heave','S_X 2nd');
ylabel('m^2 s/rad')
xlabel('Wave frequency [rad/s]')
xlim([0 1.5])

figure(112)
%subplot(2,3,5)
h=plot(w_interp,S_X(:,5),'b',OMEGA,S55_2nd_motion,'c');
set(h(1),'LineStyle','-','color',[0.0 0.2 0.6]);
set(h(2),'LineStyle','--','color',[0.0 0.2 0.0]);
legend('S_X pitch linear','S_X pitch 2nd');
ylabel('rad^2 s/rad')
xlabel('Wave frequency [rad/s]')
xlim([0 1.5])
%%
fid=fopen(sprintf('./POSTPROCESS_SRA/Spec_cond%d_seed%d0%d.dat',condition,condition,0),'r');
data=textscan(fid,'%f %f %f %f %f %f\n');
data=cell2mat(data);

S11_2_plot=interp1(OMEGA,S11_2nd_motion,w_interp,'linear','extrap');
S33_2_plot=interp1(OMEGA,S33_2nd_motion,w_interp,'linear','extrap');
S55_2_plot=interp1(OMEGA,S55_2nd_motion,w_interp,'linear','extrap');

S_plot_1=S_X(:,1);
S_plot_1(1:end)=S_plot_1(1:end)+S11_2_plot;
S_plot_3=S_X(:,3);
S_plot_3(1:end)=S_plot_3(1:end)+S33_2_plot;
S_plot_5=S_X(:,5);
S_plot_5(1:end)=S_plot_5(1:end)+ S55_2_plot;

figure(113)
%subplot(2,3,1)
h=plot(data(:,1),data(:,2),w_interp,S_plot_1);
set(h(2),'LineStyle','-','color',[0.0 0.2 0.6]);
set(h(1),'LineStyle','--','color',[0.0 0.2 0.0]);
legend('Surge TD','Surge FD');
ylabel('m^2 s/rad')
xlabel('Wave frequency [rad/s]')
xlim([0 1.5])
ylim([0 4])

figure(114)
%subplot(2,3,3)
h=plot(data(:,1),data(:,4),w_interp,S_plot_3);
set(h(2),'LineStyle','-','color',[0.0 0.2 0.6]);
set(h(1),'LineStyle','--','color',[0.0 0.2 0.0]);
legend('Heave TD','Heave FD');
ylabel('m^2 s/rad')
xlabel('Wave frequency [rad/s]')
xlim([0 1.5])

figure(115)
%subplot(2,3,5)
h=plot(data(:,1),data(:,6),w_interp,S_plot_5);
set(h(2),'LineStyle','-','color',[0.0 0.2 0.6]);
set(h(1),'LineStyle','--','color',[0.0 0.2 0.0]);
legend('Pitch TD','Pitch FD');
ylabel('rad^2 s/rad')
xlabel('Wave frequency [rad/s]')
xlim([0 1.5])

%%
fid=fopen('./POSTPROCESS_SRA/mean_area_spectrum_SRA.dat','r');
Area_specTD=textscan(fid,'%f %f %f\n');
Area_specTD=cell2mat(Area_specTD);
fclose(fid);

%Area in FD if extrapolation is excluded
Area_specFD(1)=trapz(w_interp,S_X(:,1)) +trapz(OMEGA(3:end),S11_2nd_motion(3:end));
Area_specFD(2)=trapz(w_interp,S_X(:,3)) +trapz(OMEGA(3:end),S33_2nd_motion(3:end));
Area_specFD(3)=trapz(w_interp,S_X(:,5)) +trapz(OMEGA(3:end),S55_2nd_motion(3:end));


