%name:      transfer_complex.m
%objective: calculate the complex transfer functions for excitation forces
%           and motions due to waves. 
%PLOT:      RAO      

function [F_comp,X_comp] = transfer_complex(Fexc_tot,Wave_description,X_tot,drift_sorted);
%establish complex transfer function on the form :
% H(w)=absolute_value(w)*exp(i*phase(w)) = r*exp(i*theta)

%Wave description contains : 
%number     WAVE         WAVE         WAVE         WAVE ANG.
%1:50       LENGTH       NUMBER       PERIOD       FREQUENCY

%excitation force and motions contains :
%number  REAL PART       IMAGINARY PART      ABSOLUTE VALUE  PHASE (DEGREES)    
%%
omega=Wave_description(:,5);
Abs_FX=Fexc_tot(:,4); %Absolute value 
Abs_X=X_tot(:,4); %Absolute value
Phase_FX=Fexc_tot(:,5); %Phase 
Phase_X=X_tot(:,5); %Phase

F_comp=zeros(50,6);
X_comp=zeros(50,6);
count=0;
for k = 1:6:length(Abs_FX)
    count=count+1;
    F_comp(count,1)=Abs_FX(k)*exp(1i*Phase_FX(k));
    F_comp(count,2)=Abs_FX(k+1)*exp(1i*Phase_FX(k+1));
    F_comp(count,3)=Abs_FX(k+2)*exp(1i*Phase_FX(k+2));
    F_comp(count,4)=Abs_FX(k+3)*exp(1i*Phase_FX(k+3));
    F_comp(count,5)=Abs_FX(k+4)*exp(1i*Phase_FX(k+4));
    F_comp(count,6)=Abs_FX(k+5)*exp(1i*Phase_FX(k+5));
    
    X_comp(count,1)=Abs_X(k)*exp(1i*Phase_X(k));
    X_comp(count,2)=Abs_X(k+1)*exp(1i*Phase_X(k+1));
    X_comp(count,3)=Abs_X(k+2)*exp(1i*Phase_X(k+2));
    X_comp(count,4)=Abs_X(k+3)*exp(1i*Phase_X(k+3));
    X_comp(count,5)=Abs_X(k+4)*exp(1i*Phase_X(k+4));
    X_comp(count,6)=Abs_X(k+5)*exp(1i*Phase_X(k+5));
end
%% PLOT RESULTS
omega_mean_force=drift_sorted(:,1);
mean_force=drift_sorted(:,2:10);
F_comp_plot=abs(F_comp);
X_comp_plot=abs(X_comp);

figure(2)
h=plot(omega,F_comp_plot(:,1)*10^-3,'b',omega,F_comp_plot(:,3)*10^-3,'m');
set(h(1),'LineStyle','-');
set(h(2),'LineStyle','--');
legend('F1','F3')
xlabel('Frequency [rad/s]')
ylabel('RAO [kN]')
%title('COMPLEX RAO translations')

figure(3)
h=plot(omega,F_comp_plot(:,5)*10^-3,'b');
legend('F5')
xlabel('Frequency [rad/s]')
ylabel('RAO [kNm]')
%title('COMPLEX RAO rotations')




figure(20)
subplot(2,2,1)
plot(omega,X_comp_plot(:,1:3),'-*');
legend('surge [m]','sway [m]','heave [m]')
xlabel('Wave frequency [rad/s]')
ylabel('RAO [m]')
title('COMPLEX RAO translations')

subplot(2,2,2)
plot(omega,X_comp_plot(:,4:6),'-*');
legend('roll [rad]','pitch [rad]','yaw [rad]')
xlabel('Wave frequency [rad/s]')
ylabel('RAO [rad]')
title('COMPLEX RAO rotations')

subplot(2,2,3)
plot(omega,F_comp_plot(:,1:3),'-*',omega_mean_force(:,1),mean_force(:,1:3));
legend('F1 [N]','F2 [N]','F3 [N]','F1 2nd mean[N]','F2 2nd mean[N]','F3 2nd mean[N]')
xlabel('Wave frequency [rad/s]')
ylabel('RAO [N]')
title('COMPLEX RAO Excitation forces')
xlim([0 2.5])

subplot(2,2,4)
plot(omega,F_comp_plot(:,4:6),'-*',omega_mean_force(:,1),mean_force(:,4:6));%diff_result(:,3),diff_result(:,6));%,omega,X(:,3),'+')
legend('F4 [N/rad]','F5 [N/rad]','F6 [N/rad]','F4 2nd','F5 2nd','F6 2nd')
xlabel('Wave frequency [rad/s]')
ylabel('RAO [N/rad]')
title('COMPLEX RAO Excitation moments')
xlim([0 2.5])



end
