% readSRAres  Reads in results from a single simulation 
% 

function [PlatMotions,time_SIMO,offset_motion,std_motion,freq]=readTimeDomainResults(condition,seed)

%% User-defined input
folderName=sprintf('%s%d%s%d%s%d%s%d','C:\Users\Kristine\Dropbox\MATLAB\Master Thesis\cleanup of code  2\POSTPROCESS_SRA\Test_results\Condition',condition,'\Condition',condition,'_No_wind_Seed',condition,'0',seed);
folder = folderName;
prefix = 'WFloat';


%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO output files
    MatFileName = [folder '\m001.m'];
    fid = fopen(MatFileName);
    data = textscan(fid,'%s',12,'Delimiter','\n');
    data = data{1};

    % read time info
    for ii = 1:length(data)
       eval(data{ii}) ;
    end
    time_SIMO = Time.';
    clear('Time');

    % read data
    B = [1,2];
    for ii = 1:length(B)
        if (ii==1)
            R = [12,29];
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                fname = (['B0' num2str(B(ii)) 'r' num2str(R(jj)) 'c00' num2str(kk)  ]);
                replaceinfile('\*\*\*\*\*\*\*\*\*\*\*','0.0',[folder '\' fname],'-nobak');
                load([folder '\' fname])
                eval(['var = ' fname ';']);
                for mm = 2:length(fname)-1
                   if fname(mm) == 0.0
                       fname(mm) = (fname(mm+1)+fname(mm-1))/2;
                   end
                end

            end
        end
    end 

    % summarize data in matrices
    PlatMotions = [B01r29c001 B01r29c002 B01r29c003 ...
        B01r29c004 B01r29c005 B01r29c006];
    PlatHydFor  = [B01r12c001 B01r12c002 B01r12c003 ...
        B01r12c004 B01r12c005 B01r12c006];
    NacMotions  = [B02r29c001 B02r29c002 B02r29c003 ...
        B02r29c004 B02r29c005 B02r29c006];
    
    % clear variables  
    for ii = 1:length(B)
        if (ii==1)
            R = [12,29];
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                eval(['clear ''B0' num2str(B(ii)) 'r' num2str(R(jj)) ...
                    'c00' num2str(kk) ''';']); 
            end
        end
    end
    clear('B','R','MatFileName')
    
    % Read the wind turbine results 
    % DLL output file
    fname = [folder '\DLL_WTdata.txt'];
    fid = fopen(fname);

    data = textscan(fid,'%f','Headerlines',1);
    data = data{1}; 
    data = (reshape(data,25,[])).';

    fclose(fid);
    time_DLL = data(:,1);
    HubWindX = data(:,2); % m/s
    HubWindY = data(:,3); % m/s
    HubWindZ = data(:,4); % m/s
    omega = data(:,6); % rad/s
    AeroForceX = data(:,8); % kN
    AeroMomX   = data(:,11); %kNm
    clear('data')

    % Riflex output file
    fname = [folder '\' prefix '_windturbine.asc'];
    fid = fopen(fname);
    data2 = textscan(fid,...
        '%f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',...
        'Headerlines',2);
    fclose(fid);
    time_WTRIF = data2{1};
    BlPitch = data2{4};
    genTq = data2{5};
    genPwr = data2{6}*94.4/100; % generator efficiency included

    % Read the RIFLEX force output file
    fname = [folder '\' prefix '_elmfor.asc'];
    data = load([fname]);
    time_RIFLEX = data(:,1);           
    % Tower Base
    TowerBaseAxial  = data(:,2);
    TowerBaseTors   = data(:,3);
    TowerBaseBMY    = data(:,4);
    TowerBaseBMZ    = data(:,6);
    TowerBaseShearY = data(:,8);
    TowerBaseShearZ = data(:,10);
    
    % Tower Top
    TowerTopAxial   = data(:,12);
    TowerTopTors    = data(:,13);
    TowerTopBMY     = data(:,15);
    TowerTopBMZ     = data(:,17);
    TowerTopShearY  = data(:,19);
    TowerTopShearZ  = data(:,21);
    
    % Blade 
    
    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')
    
    %%
    %Read WFloat_outmod.res
    %Freq no   Frequency    Amplitude  Phase angle
   %            (RAD/T)          (L)        (DEG)
    
    filepath=sprintf('%s%s%s%s',folder,'\',prefix,'_outmod.res');
    fileID = fopen(filepath,'r');
    string_compare=strtrim('         no      (RAD/T)          (L)        (DEG)');
    initiate=0;
    endfreq=[2427 2203 2001];
    count=0;
    freq=zeros(length(endfreq(condition)),1);
    while ~feof(fileID)
        
        line=fgetl(fileID);
        S=line;
        num_string=str2num(S);
        if initiate == 1 && count<endfreq(condition)
            count = count+1;
            freq(count,1)=num_string(2);
        end
        if strcmp(strtrim(S),string_compare)==1
            initiate=1;
        end
        
      
    end
    fclose(fileID);
%% END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions, nacelle motions, and first order potential forces:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Nacelle positions :        NacMotions (mx6) : m,m,m,deg,deg,deg
%   1st order poten. forces:   PlatHydFor (mx6) : kN,kN,kN,kNm,kNm,kNm

% Wind turbine results (from RIFLEX output file): 
%   Time variable:             time_RIFWT (nx1) : s
%   Blade pitch:               BlPitch (nx1)    : deg
%   generator power :          genPwr (nx1)     : kW (94.4% efficiency INCLUDED) 
%   generator torque:          genTq (nx1)      : kNm (LSS side)

% Wind turbine results (from DLL output file): 
%   Time variable:             time_DLL (kx1)   : s
%   Thrust (global x):         AeroForceX (kx1) : kN
%   Aero. torque (glob x):     AeroMomX (kx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (glob x):       HubWindX (kx1)   : m/s (at hub pos)
%   Wind speed (glob y):       HubWindY (kx1)   : m/s (at hub pos)
%   Wind speed (glob z):       HubWindZ (kx1)   : m/s (at hub pos)
%   Rotor speed:               omega (kx1)      : rad/s

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% Internal force results at the tower top: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerTopAxial (jx1)     : kN  (DOF1)
%   Bending mom. Y at tow base: TowerTopBMY (jx1)       : kNm (DOF3)
%   Bending mom. Z at tow base: TowerTopBMZ (jx1)       : kNm (DOF5)
%   Shear force Y at tow base:  TowerTopShearY (jx1)    : kN  (DOF7)
%   Shear force Z at tow base:  TowerTopShearZ (jx1)    : kN  (DOF9)
%   Torsional moment tow base:  TowerTopTors (jx1)      : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))

%%
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
t_start = 400;
indS = sum(time_SIMO<=t_start);
offset_motion=mean(PlatMotions(indS:end,:));
std_motion=sqrt(var(PlatMotions(indS:end,:)));
PlatMotions=PlatMotions(indS:end,:);
time_SIMO=time_SIMO(indS:end);
%% Mean values for fatigue 
% % % figure(1)
% % % plot(time_SIMO,PlatMotions(:,1),time_SIMO,PlatMotions(:,5),time_SIMO,PlatMotions(:,3))
% % % xlabel('time[s]')
% % % ylabel('motion[m/deg]')
% % % legend('surge','pitch','Heave','Location','SouthEast')
% % % title('motion','fontsize',14)
% % % 
% % % figure(2)
% % % subplot(2,1,1)
% % % plot(time_WTRIF,genPwr,time_WTRIF,genTq,'linewidth',2)
% % % xlabel('time[s]')
% % % ylabel('generator power/torque[kW/kNm]')
% % % legend('power','torque')
% % % 
% % % title('turbine results','fontsize',14)
% % % 
% % % subplot(2,1,2)
% % % plot(time_WTRIF,BlPitch,'linewidth',2)
% % % xlabel('time[s]')
% % % ylabel('blade pitch angle[deg]')
% % % 
% % % figure(3)
% % % subplot(2,1,1)
% % % plot(time_DLL,AeroForceX,'linewidth',2)
% % % xlabel('time[s]')
% % % ylabel('Thrust[kN]')
% % % 
% % % title('aerodynamic results','fontsize',14)
% % % 
% % % subplot(2,1,2)
% % % plot(time_DLL,omega,'linewidth',2)
% % % xlabel('time[s]')
% % % ylabel('roter speed[rad/s]')

%% output
% % 
% % [Thrust_peaks Thrust_valleys] = findinflections(0,AeroForceX(indS:end));
% % if length(Thrust_peaks)~=length(Thrust_valleys)
% %     k=abs(length(Thrust_peaks)-length(Thrust_valleys));
% %     if length(Thrust_peaks)>length(Thrust_valleys)
% %         Thrust_peaks=Thrust_peaks(1:end-k);
% %     else
% %         Thrust_valleys=Thrust_valleys(1:end-k);
% %     end
% % end
% % Thrust_mean = 0.5*mean(AeroForceX(Thrust_peaks)+AeroForceX(Thrust_valleys));
% % 
% % [Power_peaks Power_valleys] = findinflections(0,genPwr(indS:end));
% % if length(Power_peaks)~=length(Power_valleys)
% %     k=abs(length(Power_peaks)-length(Power_valleys));
% %     if length(Power_peaks)>length(Power_valleys);
% %         Power_peaks=Power_peaks(1:end-k);
% %     else
% %         Power_valleys=Power_valleys(1:end-k);
% %     end
% % end
% % Power_mean = 0.5*mean(genPwr(Power_peaks)+genPwr(Power_valleys));
% % 
% % [Torque_peaks Torque_valleys] = findinflections(0,genTq(indS:end));
% % if length(Torque_peaks)~=length(Torque_valleys)
% %     k=abs(length(Torque_peaks)-length(Torque_valleys));
% %     if length(Torque_peaks)>length(Torque_valleys);
% %         Torque_peaks=Torque_peaks(1:end-k);
% %     else
% %         Torque_valleys=Torque_valleys(1:end-k);
% %     end
% % end
% % Torque_mean = 0.5*mean(genTq(Torque_peaks)+genTq(Torque_valleys));
% % 
% % filename=sprintf('Result_cond%d_seed%d.txt',condition,seed);
% % Write_result=fopen(filename,'w');
% % fprintf(Write_result,' Mean offset Surge [m]    :%d\n', offset_motion(1,1));
% % fprintf(Write_result,' Mean offset Pitch [deg]  :%d\n', offset_motion(1,5));
% % fprintf(Write_result,' Mean rotor speed  [rad/s]:%d\n', mean(omega(end-400:end)));
% % fprintf(Write_result,' Mean thrust force [kN]   :%d\n', Thrust_mean);
% % fprintf(Write_result,' Mean torque       [kNm]  :%d\n', Torque_mean);
% % fprintf(Write_result,' Mean Power        [kW]   :%d\n', Power_mean);
% % fprintf(Write_result,' Mean blade pitch  [deg]  :%d\n', mean(BlPitch(end-400:end)));
% % fprintf(Write_result,' STD: surge sway heave roll pitch yaw\n %f %f %f %f %f %f\n', std_motion);
% % fclose(Write_result);
% % fprintf('%d\n', offset_motion(1));
% % fprintf('%d\n', offset_motion(5));
% % fprintf('%d\n', mean(omega(indS:end)));
% % fprintf('%d\n', Thrust_mean);
% % fprintf('%d\n', Torque_mean);
% % fprintf('%d\n', Power_mean);
% % fprintf('%d\n', mean(BlPitch(indS:end)));


end

