% readSRAres  Reads in results from a single simulation 
% In courtesy of Erin E. Bachynski
function [PlatMotions,time_SIMO,offset_motion,std_motion,HubWindX,time_DLL,AeroForceX]=readTimeDomainResultsTurb(windspeed,seed)

%% User-defined input
name=sprintf('%s%d%s','C:\Users\Kristine\Dropbox\MATLAB\2015\Project Thesis\Result_files\Turb_cond',windspeed,'_test');%,'ms_seed',seed);
folder = name;
prefix = 'WFloat'%'wtfixed';

%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO output files
    MatFileName = [folder '\m001.m'];
    fid = fopen(MatFileName);
    data = textscan(fid,'%s',12,'Delimiter','\n');
    data = data{1};

    % read time info
    for ii = 1:length(data)
       eval(data{ii}) ;
    end
    time_SIMO = Time.';
    clear('Time');

    % read data
    B = [1,2];
    for ii = 1:length(B)
        if (ii==1)
            R = [12,29];
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                fname = (['B0' num2str(B(ii)) 'r' num2str(R(jj)) 'c00' num2str(kk)  ]);
                replaceinfile('\*\*\*\*\*\*\*\*\*\*\*','0.0',[folder '\' fname],'-nobak');
                load([folder '\' fname])
                eval(['var = ' fname ';']);
                for mm = 2:length(fname)-1
                   if fname(mm) == 0.0
                       fname(mm) = (fname(mm+1)+fname(mm-1))/2;
                   end
                end

            end
        end
    end 

    % summarize data in matrices
    PlatMotions = [B01r29c001 B01r29c002 B01r29c003 ...
        B01r29c004 B01r29c005 B01r29c006];
    PlatHydFor  = [B01r12c001 B01r12c002 B01r12c003 ...
        B01r12c004 B01r12c005 B01r12c006];
    NacMotions  = [B02r29c001 B02r29c002 B02r29c003 ...
        B02r29c004 B02r29c005 B02r29c006];
    
    % clear variables  
    for ii = 1:length(B)
        if (ii==1)
            R = [12,29];
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                eval(['clear ''B0' num2str(B(ii)) 'r' num2str(R(jj)) ...
                    'c00' num2str(kk) ''';']); 
            end
        end
    end
    clear('B','R','MatFileName')
    
    % Read the wind turbine results 
    % DLL output file
    fname = [folder '\DLL_WTdata.txt'];
    fid = fopen(fname);

    data = textscan(fid,'%f','Headerlines',1);
    data = data{1}; 
    data = (reshape(data,25,[])).';

    fclose(fid);
    time_DLL = data(:,1);
    HubWindX = data(:,2); % m/s
    HubWindY = data(:,3); % m/s
    HubWindZ = data(:,4); % m/s
    omega = data(:,6); % rad/s
    AeroForceX = data(:,8); % kN
    AeroMomX   = data(:,11); %kNm
    clear('data')

    % Riflex output file
    fname = [folder '\' prefix '_windturbine.asc'];
    fid = fopen(fname);
    data2 = textscan(fid,...
        '%f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',...
        'Headerlines',2);
    fclose(fid);
    time_WTRIF = data2{1};
    BlPitch = data2{4};
    genTq = data2{5};
    genPwr = data2{6}*94.4/100; % generator efficiency included

    % Read the RIFLEX force output file
    fname = [folder '\' prefix '_elmfor.asc'];
    data = load([fname]);
    time_RIFLEX = data(:,1);           
    % Tower Base
    TowerBaseAxial  = data(:,2);
    TowerBaseTors   = data(:,3);
    TowerBaseBMY    = data(:,4);
    TowerBaseBMZ    = data(:,6);
    TowerBaseShearY = data(:,8);
    TowerBaseShearZ = data(:,10);
    
    % Tower Top
    TowerTopAxial   = data(:,12);
    TowerTopTors    = data(:,13);
    TowerTopBMY     = data(:,15);
    TowerTopBMZ     = data(:,17);
    TowerTopShearY  = data(:,19);
    TowerTopShearZ  = data(:,21);
    
    % Blade 
    
    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data2','samp')
    
%% END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions, nacelle motions, and first order potential forces:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Nacelle positions :        NacMotions (mx6) : m,m,m,deg,deg,deg
%   1st order poten. forces:   PlatHydFor (mx6) : kN,kN,kN,kNm,kNm,kNm

% Wind turbine results (from RIFLEX output file): 
%   Time variable:             time_RIFWT (nx1) : s
%   Blade pitch:               BlPitch (nx1)    : deg
%   generator power :          genPwr (nx1)     : kW (94.4% efficiency INCLUDED) 
%   generator torque:          genTq (nx1)      : kNm (LSS side)

% Wind turbine results (from DLL output file): 
%   Time variable:             time_DLL (kx1)   : s
%   Thrust (global x):         AeroForceX (kx1) : kN
%   Aero. torque (glob x):     AeroMomX (kx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (glob x):       HubWindX (kx1)   : m/s (at hub pos)
%   Wind speed (glob y):       HubWindY (kx1)   : m/s (at hub pos)
%   Wind speed (glob z):       HubWindZ (kx1)   : m/s (at hub pos)
%   Rotor speed:               omega (kx1)      : rad/s

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% Internal force results at the tower top: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerTopAxial (jx1)     : kN  (DOF1)
%   Bending mom. Y at tow base: TowerTopBMY (jx1)       : kNm (DOF3)
%   Bending mom. Z at tow base: TowerTopBMZ (jx1)       : kNm (DOF5)
%   Shear force Y at tow base:  TowerTopShearY (jx1)    : kN  (DOF7)
%   Shear force Z at tow base:  TowerTopShearZ (jx1)    : kN  (DOF9)
%   Torsional moment tow base:  TowerTopTors (jx1)      : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))

%%
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
t_start = 400;
indS = sum(time_SIMO<=t_start);
indSDLL=sum(time_DLL<=t_start);
AeroForceX=AeroForceX(indSDLL:end);
time_DLL=time_DLL(indSDLL:end);
offset_motion=mean(PlatMotions(indS:end,:));
std_motion=sqrt(var(PlatMotions(indS:end,:)));
PlatMotions=PlatMotions(indS:end,:);
time_SIMO=time_SIMO(indS:end);

%           

end

